const path = require('path');
const fs = require('fs');
const messages = require('./messages');
const copyDir = require('./utils/copy-dir');
const install = require('./utils/install');
const { devDependencies, dependencies } = require('./packages');

function installWithMessageFactory({ projectName, projectPath }) {
  return function installWithMessage() {
    return install({
      projectName,
      projectPath,
      devDependencies,
      dependencies,
    });
  };
}

module.exports = function createAgilePlayApp(projectName) {
  if (!projectName) {
    console.log(messages.missingProjectName());
    process.exit(1);
  }

  if (fs.existsSync(projectName)) {
    console.log(messages.alreadyExists());
    process.exit(1);
  }

  const projectPath = `${process.cwd()}/${projectName}`;
  const templatePath = path.resolve(__dirname, '../templates/default');

  copyDir({
    templatePath,
    projectPath,
    projectName,
  })
    .then(installWithMessageFactory({ projectName, projectPath }))
    .catch((err) => {
      throw err;
    });
};
