const execa = require('execa');
const getInstallCmd = require('./get-install-cmd');
const output = require('./output');
const messages = require('../messages');

function getInstallArgs(cmd, packages, isDev) {
  if (cmd === 'npm') {
    const args = ['install'];
    if (isDev) {
      args.push('--save-dev', '--save-exact');
    } else {
      args.push('--save', '--save-exact');
    }
    return args.concat(packages, ['--verbose']);
  }

  if (cmd === 'yarn') {
    const args = ['add'];
    if (isDev) {
      args.push('-D');
    }
    return args.concat(packages);
  }
}

module.exports = function install({ projectName, projectPath, devDependencies, dependencies }) {
  const installCmd = getInstallCmd();
  const installDevArgs = getInstallArgs(installCmd, devDependencies, true);
  const installArgs = getInstallArgs(installCmd, dependencies, false);

  console.log(messages.installing(devDependencies.concat(dependencies)));
  process.chdir(projectPath);

  return new Promise((resolve, reject) => {
    const stopInstallSpinner = output.wait('Installing modules');

    execa(installCmd, installDevArgs)
      .then(execa(installCmd, installArgs))
      .then(() => {
        stopInstallSpinner();
        output.success(`Installed dependencies for ${projectName}`);
        resolve();
      })
      .catch(() => {
        stopInstallSpinner();
        console.log(messages.installError(packages));
        return reject(new Error(`${installCmd} installation failed`));
      });
  });
};
